==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicSymbolSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicSymbolSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicSymbolSeriesBaseDescriptionMetadata.a == null) {
                GeographicSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicSymbolSeriesBaseDescriptionMetadata.c(GeographicSymbolSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicSymbolSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicSymbolSeriesBaseDescriptionMetadata.b(a);
            a.ac("GeographicSymbolSeriesBase", GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicSymbolSeriesBaseDescriptionMetadata.$t = markType(GeographicSymbolSeriesBaseDescriptionMetadata, 'GeographicSymbolSeriesBaseDescriptionMetadata');
    GeographicSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicSymbolSeriesBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicSymbolSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicSymbolSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicSymbolSeriesBaseDescriptionMetadata.a == null) {
                GeographicSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicSymbolSeriesBaseDescriptionMetadata.c(GeographicSymbolSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicSymbolSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicSymbolSeriesBaseDescriptionMetadata.b(a);
            a.ad("GeographicSymbolSeriesBase", GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicSymbolSeriesBaseDescriptionMetadata.$t = markType(GeographicSymbolSeriesBaseDescriptionMetadata, 'GeographicSymbolSeriesBaseDescriptionMetadata');
    GeographicSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicSymbolSeriesBaseDescriptionMetadata;
})();
